summaryrefslogtreecommitdiff
path: root/src/gui/serverdialog.cpp
diff options
context:
space:
mode:
authorAndrei Karas <akaras@inbox.ru>2012-01-21 17:02:34 +0300
committerAndrei Karas <akaras@inbox.ru>2012-01-21 17:02:34 +0300
commit30c7f7c0e0d3f5801e968077237103ee0dfadf7b (patch)
tree8729e98da01a6f01f1ca40b171d3f04412536f41 /src/gui/serverdialog.cpp
parentdaf84780d386ee122ae4b4bd37b1e918f93fb202 (diff)
downloadplus-30c7f7c0e0d3f5801e968077237103ee0dfadf7b.tar.gz
plus-30c7f7c0e0d3f5801e968077237103ee0dfadf7b.tar.bz2
plus-30c7f7c0e0d3f5801e968077237103ee0dfadf7b.tar.xz
plus-30c7f7c0e0d3f5801e968077237103ee0dfadf7b.zip
Change server list url to manaplus host.
Diffstat (limited to 'src/gui/serverdialog.cpp')
-rw-r--r--src/gui/serverdialog.cpp7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/gui/serverdialog.cpp b/src/gui/serverdialog.cpp
index 019ea9f1c..39ff19a89 100644
--- a/src/gui/serverdialog.cpp
+++ b/src/gui/serverdialog.cpp
@@ -609,9 +609,12 @@ void ServerDialog::downloadServerList()
if (listFile.empty())
listFile = config.getStringValue("onlineServerList");
// Fall back to manasource.org when neither branding nor config set it
if (listFile.empty())
- listFile = "http://manasource.org/serverlist.xml";
+ {
+ listFile = "http://manaplus.evolonline.org/"
+ "serverlist.xml/serverlist.xml";
+ }
if (mDownload)
{
@@ -609,9 +609,12 @@ void ServerDialog::downloadServerList()
if (listFile.empty())
listFile = config.getStringValue("onlineServerList");
- // Fall back to manasource.org when neither branding nor config set it
+ // Fall back to manaplus.evolonline.org when neither branding nor config set it
if (listFile.empty())